@@ -7,7 +7,7 @@ from django.conf import settings  # import the settingsfile
 # logger = logging.getLogger('django.debug')
 
 STATIC_URL = getattr(settings, 'STATIC_URL')
-BSVER = '3.2.0'
+BSVER = '3.3.0'
 BOOTSWATCH_META_FILE = "bootswatch_meta.json"
 
 
@@ -49,6 +49,13 @@ def scan_themes():
     sroot = os.path.dirname(os.path.realpath(__file__))
     static_base = "{}bootstrap-{}".format(STATIC_URL, BSVER)
 
+    # Bootstrap base css
+    _BS_BASE = {
+        'css': os.path.join(static_base, "css/bootstrap.css"),
+        'cssMin': os.path.join(static_base, "css/bootstrap.min.css"),
+        'cssCdn': BOOTSTRAP_SETTINGS.get('css_cdn').format(bsver=BSVER),
+    }
+
     if not sroot:
         return _THEMES_CACHED
 
@@ -66,8 +73,8 @@ def scan_themes():
     # Fill in the default bs theme
     _THEMES_CACHED['bootstrap'] = {
         'name': 'Bootstrap',
-        'css_url': os.path.join(static_base, "css/bootstrap-theme.css"),
-        'css_min_url': os.path.join(static_base, "css/bootstrap-theme.min.css"),
+        'css': os.path.join(static_base, "css/bootstrap-theme.css"),
+        'cssMin': os.path.join(static_base, "css/bootstrap-theme.min.css"),
         'description': 'Default Bootstrap',
         'thumbnail': '',
         'less': '',
@@ -77,21 +84,14 @@ def scan_themes():
         'cssMin': '',
     }
 
-    # Bootstrap base css
-    _BS_BASE = {
-        'css_url': os.path.join(static_base, "css/bootstrap.css"),
-        'css_min_url': os.path.join(static_base, "css/bootstrap.min.css"),
-        'cssCdn': BOOTSTRAP_SETTINGS.get('css_cdn').format(bsver=BSVER),
-    }
-
     # Create the theme data from the meta data
     for t in bsw_meta['themes']:
         t_name = t['name'].lower()
         _THEMES_CACHED[t_name] = t
         _THEMES_CACHED[t_name].update(
             {
-                'css_url': "{}/{}_css/bootstrap.css".format(static_base, t_name),
-                'css_min_url': "{}/{}_css/bootstrap.min.css".format(static_base, t_name),
+                'css': "{}/{}_css/bootstrap.css".format(static_base, t_name),
+                'cssMin': "{}/{}_css/bootstrap.min.css".format(static_base, t_name),
             }
         )
 
@@ -130,10 +130,10 @@ def bootstrap_urls(context):
     extras = "media=\"screen\""
     resp = {'BOOTSTRAP_THEMES': _THEME_LIST}
 
-    url_key = 'css_min_url'
+    url_key = 'cssMin'
 
     if debug:
-        url_key = 'css_url'
+        url_key = 'css'
     elif BOOTSTRAP_SETTINGS['use_cdn']:
         url_key = 'cssCdn'
 
